@@ -69,12 +69,6 @@
  * This section is only here to supress warnings, and should not be displayed.
  */
 
-/**
- * GCR_DATA_ERROR:
- *
- * The #GError domain for data parsing errors.
- */
-
 G_LOCK_DEFINE_STATIC (modules);
 static GList *all_modules = NULL;
 static gboolean initialized_modules = FALSE;
@@ -136,11 +130,7 @@ _gcr_initialize_library (void)
 {
 	static gint gcr_initialize = 0;
 
-#if GLIB_CHECK_VERSION (2,29,90)
 	if (g_atomic_int_add (&gcr_initialize, 1) == 0)
-#else
-	if (g_atomic_int_exchange_and_add (&gcr_initialize, 1) == 0)
-#endif
 		return;
 
 	/* Initialize the libgcrypt library if needed */
